==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpSearchQuery.java <==
package io.qt.help;


/**
 * <p>Contains the field name and the associated search term</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpsearchquery.html">QHelpSearchQuery</a></p>
 */
public class QHelpSearchQuery extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qhelpsearchquery-obsolete.html#FieldName-enum">QHelpSearchQuery::FieldName</a></p>
     */
    public enum FieldName implements io.qt.QtEnumerator {
        DEFAULT(0),
        FUZZY(1),
        WITHOUT(2),
        PHRASE(3),
        ALL(4),
        ATLEAST(5);

        private FieldName(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FieldName resolve(int value) {
            switch (value) {
            case 0: return DEFAULT;
            case 1: return FUZZY;
            case 2: return WITHOUT;
            case 3: return PHRASE;
            case 4: return ALL;
            case 5: return ATLEAST;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquery.html#QHelpSearchQuery">QHelpSearchQuery::QHelpSearchQuery()</a></p>
     */
    public QHelpSearchQuery(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QHelpSearchQuery instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquery.html#QHelpSearchQuery-1">QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)</a></p>
     */
    public QHelpSearchQuery(io.qt.help.QHelpSearchQuery.FieldName field, java.util.Collection<java.lang.String> wordList_){
        super((QPrivateConstructor)null);
        initialize_native(this, field, wordList_);
    }
    
    private native static void initialize_native(QHelpSearchQuery instance, io.qt.help.QHelpSearchQuery.FieldName field, java.util.Collection<java.lang.String> wordList_);
    
    @io.qt.QtUninvokable
    public final void setFieldName(io.qt.help.QHelpSearchQuery.FieldName fieldName){
        setFieldName_native_cref_QHelpSearchQuery_FieldName(QtJambi_LibraryUtilities.internal.nativeId(this), fieldName.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFieldName_native_cref_QHelpSearchQuery_FieldName(long __this__nativeId, int fieldName);
    
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpSearchQuery.FieldName fieldName(){
        return io.qt.help.QHelpSearchQuery.FieldName.resolve(fieldName_native(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int fieldName_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setWordList(java.util.Collection<java.lang.String> wordList){
        setWordList_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), wordList);
    }
    
    @io.qt.QtUninvokable
    private native void setWordList_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> wordList);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.String> wordList(){
        return wordList_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.String> wordList_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQuery(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QHelpSearchQuery clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QHelpSearchQuery clone_native(long __this_nativeId);
}

==> qtjambi-help-6.3.4-sources.jar: io/qt/help/QHelpSearchQuery.java <==
package io.qt.help;


/**
 * <p>Java wrapper for Qt class QHelpSearchQuery</p>
 */
public class QHelpSearchQuery extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum QHelpSearchQuery::FieldName</p>
     */
    public enum FieldName implements io.qt.QtEnumerator {
        DEFAULT(0),
        FUZZY(1),
        WITHOUT(2),
        PHRASE(3),
        ALL(4),
        ATLEAST(5);

        private FieldName(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FieldName resolve(int value) {
            switch (value) {
            case 0: return DEFAULT;
            case 1: return FUZZY;
            case 2: return WITHOUT;
            case 3: return PHRASE;
            case 4: return ALL;
            case 5: return ATLEAST;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QHelpSearchQuery(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QHelpSearchQuery instance);
    
    public QHelpSearchQuery(io.qt.help.QHelpSearchQuery.FieldName field, java.util.Collection<java.lang.String> wordList_){
        super((QPrivateConstructor)null);
        initialize_native(this, field, wordList_);
    }
    
    private native static void initialize_native(QHelpSearchQuery instance, io.qt.help.QHelpSearchQuery.FieldName field, java.util.Collection<java.lang.String> wordList_);
    
    @io.qt.QtUninvokable
    public final void setFieldName(io.qt.help.QHelpSearchQuery.FieldName fieldName){
        setFieldName_native_cref_QHelpSearchQuery_FieldName(QtJambi_LibraryUtilities.internal.nativeId(this), fieldName.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFieldName_native_cref_QHelpSearchQuery_FieldName(long __this__nativeId, int fieldName);
    
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpSearchQuery.FieldName fieldName(){
        return io.qt.help.QHelpSearchQuery.FieldName.resolve(fieldName_native(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int fieldName_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setWordList(java.util.Collection<java.lang.String> wordList){
        setWordList_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), wordList);
    }
    
    @io.qt.QtUninvokable
    private native void setWordList_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> wordList);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.String> wordList(){
        return wordList_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.String> wordList_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQuery(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QHelpSearchQuery clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QHelpSearchQuery clone_native(long __this_nativeId);
}
